<?php
/**
 * WCFM Marketplace plugin core
 *
 * Plugin Frontend Controler
 *
 * @author 		WC Lovers
 * @package 	wcfmmp/core
 * @version   1.0.0
 */
 
class WCFMmp_Frontend {
	
	public function __construct() {
		global $WCFM, $WCFMmp;
		
		// Show Product Sold By Label
		add_action( 'woocommerce_product_meta_start',	array( &$this, 'wcfmmp_sold_by_product' ), 50 );
		
		// Show Product Sold By in Loop
		add_action('woocommerce_after_shop_loop_item_title', array( $this, 'wcfmmp_sold_by_product' ), 50 );
		
		// Show Product Sold By in Cart
		add_filter('woocommerce_get_item_data', array( &$this, 'wcfmmp_sold_by_cart' ), 50, 2 );
		
		// My Account Vendor Registration URL
		add_action( 'woocommerce_register_form_end', array( &$this, 'wcfmmp_become_vendor_link' ) );
		
		// My Account Dashboard Menu
		add_filter( 'woocommerce_account_menu_items', array( &$this, 'wcfm_dashboard_my_account_menu_items' ), 210 );
		add_filter( 'woocommerce_get_endpoint_url', array( &$this,  'wcfm_dashboard_my_account_endpoint_redirect'), 10, 4 );
		
		//enqueue scripts
		add_action( 'wp_enqueue_scripts', array( &$this, 'wcfmmp_scripts' ), 20 );
		
		//enqueue styles
		add_action( 'wp_enqueue_scripts', array( &$this, 'wcfmmp_styles' ), 20 );
		
	}
	
	/**
	 * Show sold by at Product Page
	 */
	function wcfmmp_sold_by_product() {
		global $WCFM, $WCFMmp, $product;
		
		if ( wcfm_is_store_page() ) return;
		
		if( $WCFMmp->wcfmmp_vendor->is_vendor_sold_by() ) {
			$product_id = $product->get_id();
			$vendor_id = $WCFM->wcfm_vendor_support->wcfm_get_vendor_id_from_product( $product_id );
			if( $vendor_id ) {
				if( apply_filters( 'wcfmmp_is_allow_sold_by', true, $vendor_id ) && $WCFM->wcfm_vendor_support->wcfm_vendor_has_capability( $vendor_id, 'sold_by' ) ) {
					$sold_by_text = $WCFMmp->wcfmmp_vendor->sold_by_label();
					$store_name = $WCFM->wcfm_vendor_support->wcfm_get_vendor_store_by_vendor( absint($vendor_id) );
					
					do_action('before_wcfmmp_sold_by_label_product_page', $vendor_id );
					echo '<div class="wcfmmp_sold_by_wrapper"><span class="wcfmmp_sold_by_label">' . $sold_by_text . ':&nbsp;</span>' . $store_name . '</div>';
					$WCFMmp->wcfmmp_reviews->show_star_rating( 0, $vendor_id );
					do_action('after_wcfmmp_sold_by_label_product_page', $vendor_id );
				}
			}
		}
	}
	
	/**
	 * Show sold by at Cart Page
	 */
	function wcfmmp_sold_by_cart( $cart_item_meta, $cart_item ) {
		global $WCFM, $WCFMmp;
		
		if( $WCFMmp->wcfmmp_vendor->is_vendor_sold_by() ) {
			$product_id = $cart_item['product_id'];
			$vendor_id = $WCFM->wcfm_vendor_support->wcfm_get_vendor_id_from_product( $product_id );
			if( $vendor_id ) {
				if( apply_filters( 'wcfmmp_is_allow_sold_by', true, $vendor_id ) && $WCFM->wcfm_vendor_support->wcfm_vendor_has_capability( $vendor_id, 'sold_by' ) ) {
					$sold_by_text = $WCFMmp->wcfmmp_vendor->sold_by_label();
					$store_name = $WCFM->wcfm_vendor_support->wcfm_get_vendor_store_by_vendor( absint($vendor_id) );
					
					do_action('before_wcfmmp_sold_by_label_cart_page', $vendor_id );
					$cart_item_meta = array_merge( $cart_item_meta, array( array( 'name' => $sold_by_text, 'value' => $store_name ) ) );
					do_action('after_wcfmmp_sold_by_label_cart_page', $vendor_id );
				}
			}
		}
		return $cart_item_meta;
	}
	
	/**
	 * WC Registration Become Vendor link
	 */
	function wcfmmp_become_vendor_link() {
		global $WCFM, $WCFMmp;
		
		if( apply_filters( 'wcfm_is_allow_my_account_become_vendor', true ) && WCFMmp_Dependencies::wcfmvm_plugin_active_check() ) {
			echo '<div class="wcfmmp_become_vendor_link">';
			$wcfm_memberships = get_wcfm_memberships();
			if( !empty( $wcfm_memberships ) ) {
				echo '<a href="' . get_wcfm_membership_url() . '">' . __( 'Become a Vendor', 'wc-multivendor-marketplace' ) . '</a>';
			} else {
				echo '<a href="' . get_wcfm_registration_page() . '">' . __( 'Become a Vendor', 'wc-multivendor-marketplace' ) . '</a>';
			}
			echo '</div>';
		}
	}
	
	/**
	 * WC My Account Dashboard Link
	 */
	function wcfm_dashboard_my_account_menu_items( $items ) {
		global $WCFM, $WCFMmp;
		
		if( wcfm_is_vendor() ) {
			$items = array_slice($items, 0, count($items) - 2, true) +
																		array(
																					"wcfm-store-manager" => __( 'Store Manager', 'wc-multivendor-marketplace' )
																					) +
																		array_slice($items, count($items) - 2, count($items) - 1, true) ;
		}
																	
		return $items;
	}
	
	function wcfm_dashboard_my_account_endpoint_redirect( $url, $endpoint, $value, $permalink ) {
		if( $endpoint == 'wcfm-store-manager')
      $url = get_wcfm_url();
    return $url;
	}
	
	/**
	 * WCFMmp Store JS
	 */
	function wcfmmp_scripts() {
 		global $WCFM, $WCFMmp, $wp, $WCFM_Query;
 		
 		if( isset( $_REQUEST['fl_builder'] ) ) return;
 		
 		if( wcfmmp_is_store_page() ) {
 			$WCFM->library->load_blockui_lib();
 			
			// Store JS
			wp_enqueue_script( 'wcfmmp_store_js', $WCFMmp->library->js_lib_url . 'store/wcfmmp-script-store.js', array('jquery' ), $WCFMmp->version, true );
			
			$scheme  = is_ssl() ? 'https' : 'http';
			$api_key = isset( $WCFMmp->wcfmmp_marketplace_options['wcfm_google_map_api'] ) ? $WCFMmp->wcfmmp_marketplace_options['wcfm_google_map_api'] : '';
			if ( $api_key ) {
				wp_enqueue_script( 'wcfm-wcmarketplace-setting-google-maps', $scheme . '://maps.googleapis.com/maps/api/js?key=' . $api_key . '&libraries=places' );
			}
			
			$wcfm_reviews_messages = get_wcfm_reviews_messages();
			wp_localize_script( 'wcfmmp_store_js', 'wcfm_reviews_messages', $wcfm_reviews_messages );
		}
		
		if( wcfmmp_is_stores_list_page() ) {
			wp_enqueue_script( 'wcfmmp_store_list_js', $WCFMmp->library->js_lib_url . 'store/wcfmmp-script-store-lists.js', array('jquery' ), $WCFMmp->version, true );
		}
 	}
 	
 	/**
 	 * WCFMmp Core CSS
 	 */
 	function wcfmmp_styles() {
 		global $WCFM, $WCFMmp, $wp, $WCFM_Query;
 		
 		if( isset( $_REQUEST['fl_builder'] ) ) return;
 		
 		if( wcfmmp_is_store_page() ) {
			// Store CSS
			wp_enqueue_style( 'wcfmmp_store_css',  $WCFMmp->library->css_lib_url . 'store/wcfmmp-style-store.css', array(), $WCFMmp->version );
			
			// Store Responsive CSS
			wp_enqueue_style( 'wcfmmp_store_responsive_css',  $WCFMmp->library->css_lib_url . 'store/wcfmmp-style-store-responsive.css', array(), $WCFMmp->version );
		}
		
		if( wcfmmp_is_stores_list_page() ) {
			wp_enqueue_style( 'wcfmmp_stores_list_css',  $WCFMmp->library->css_lib_url . 'store/wcfmmp-style-stores-list.css', array(), $WCFMmp->version );
		}
 	}
	
}