<?php
/**
 * WCFMmp plugin core
 *
 * WCfMmp Shipping
 *
 * @author 		WC Lovers
 * @package 	wcfmmp/core
 * @version   1.0.0
 */
 
class WCFMmp_Shipping {
	
	public function __construct() {
		global $WCFM, $WCFMmp;
    //Load Vendor Shipping Settings
		add_action( 'wcfm_marketplace_shipping', array( &$this, 'wcfmmp_load_shipping_view' ) );
    
    //Save Vendor Shipping Settings
    add_action('wcfm_vendor_settings_update' , array( &$this,'wcfmmp_vendor_shipping_settings_update' ), 10, 2 );
    
    // split woocommerce shipping packages
    add_filter('woocommerce_cart_shipping_packages', array(&$this, 'wcfmmp_split_shipping_packages'), 0);

    // Add extra vendor_id to shipping packages
    add_action('woocommerce_checkout_create_order_shipping_item', array(&$this, 'wcfmmp_add_meta_date_in_shipping_package'), 10, 4);

    // Rename woocommerce shipping packages
    add_filter('woocommerce_shipping_package_name', array(&$this, 'wcfmmp_shipping_package_name'), 10, 3);
    
	}
	
	public function get_shipping_cost() {
		global $WCFM, $WCFMmp;
		
		return 0;
	}
	
	public function get_shipping_tax_cost() {
		global $WCFM, $WCFMmp;
		
		return 0;
	}
  
  public function wcfmmp_load_shipping_view() {
    global $WCFM, $WCFMmp;
    $WCFMmp->template->get_template( 'shipping/wcfmmp-view-shipping-settings.php' );
  }
  
  public function wcfmmp_vendor_shipping_settings_update( $user_id, $wcfm_settings_form ) {
    
    if(!isset($wcfm_settings_form['wcfmmp_shipping']['_wcfmmp_user_shipping_enable'])) {
      $wcfm_settings_form['wcfmmp_shipping']['_wcfmmp_user_shipping_enable'] = 'no';
    }

    update_user_meta($user_id, '_wcfmmp_shipping', $wcfm_settings_form['wcfmmp_shipping']);
    
    if(!empty( $wcfm_settings_form['wcfmmp_shipping']['_wcfmmp_user_shipping_type']) && $wcfm_settings_form['wcfmmp_shipping']['_wcfmmp_user_shipping_type'] == 'by_country') {
      //print_r($wcfm_settings_form);
      if(isset($wcfm_settings_form['wcfmmp_shipping_by_country'])) {
        update_user_meta($user_id, '_wcfmmp_shipping_by_country', $wcfm_settings_form['wcfmmp_shipping_by_country']);
      }
      // Shipping Rates
      if(isset($wcfm_settings_form['wcfmmp_shipping_rates']) && !empty($wcfm_settings_form['wcfmmp_shipping_rates'])) {
        $wcfmmp_country_rates = array();
        $wcfmmp_state_rates   = array(); 
        foreach( $wcfm_settings_form['wcfmmp_shipping_rates'] as $wcfmmp_shipping_rates ) {
          if( $wcfmmp_shipping_rates['wcfmmp_country_to'] ) {
            if( $wcfmmp_shipping_rates['wcfmmp_shipping_state_rates'] && !empty( $wcfmmp_shipping_rates['wcfmmp_shipping_state_rates'] ) ) {
              foreach( $wcfmmp_shipping_rates['wcfmmp_shipping_state_rates'] as $wcfmmp_shipping_state_rates ) {
                if( $wcfmmp_shipping_state_rates['wcfmmp_state_to'] ) {
                  $wcfmmp_state_rates[$wcfmmp_shipping_rates['wcfmmp_country_to']][$wcfmmp_shipping_state_rates['wcfmmp_state_to']] = $wcfmmp_shipping_state_rates['wcfmmp_state_to_price'];
                }
              }
            }
            $wcfmmp_country_rates[$wcfmmp_shipping_rates['wcfmmp_country_to']] = $wcfmmp_shipping_rates['wcfmmp_country_to_price'];
          }
        }
        update_user_meta( $user_id, '_wcfmmp_country_rates', $wcfmmp_country_rates );
        update_user_meta( $user_id, '_wcfmmp_state_rates', $wcfmmp_state_rates );
      }
    }
    
    if( !empty( $wcfm_settings_form['wcfmmp_shipping']['_wcfmmp_user_shipping_type'] ) && $wcfm_settings_form['wcfmmp_shipping']['_wcfmmp_user_shipping_type'] == 'by_zone') {

      //print_r($wcfm_settings_form);
      $all_allowed_countries = WC()->countries->get_allowed_countries();
      $location = array();
      $zone_id = 0;
      //print_r($all_allowed_countries);
      if(!empty($wcfm_settings_form['wcfmmp_shipping_zone'])) {
        foreach( $wcfm_settings_form['wcfmmp_shipping_zone'] as $shipping_zone ) {
          if( isset($shipping_zone['_zone_id'] ) && $shipping_zone['_zone_id'] != 0 ) {
            $zone_id = $shipping_zone['_zone_id'];
            if(isset( $shipping_zone['_limit_zone_location'] ) && $shipping_zone['_limit_zone_location'] ) {
              if(!empty($shipping_zone['_select_zone_country'])) {
                $country_array = array();
                foreach ( $shipping_zone['_select_zone_country'] as $zone_country ) {
                  $country_array[] = array(
                    'code' => $zone_country,
                    'type'  => 'country'
                  );
                }
                $location = array_merge( $location, $country_array );
              }
              if(!empty($shipping_zone['_select_zone_states'])) {
                $state_array = array();
                foreach ( $shipping_zone['_select_zone_states'] as $zone_state ) {
                  $state_array[] = array(
                    'code' => $zone_state,
                    'type'  => 'state'
                  );
                }
                $location = array_merge( $location, $state_array );
              }
              
              if(!empty($shipping_zone['_select_zone_postcodes'])) {
                $postcode_array = array();
                $zone_postcodes = array_map('trim', explode(',', $shipping_zone['_select_zone_postcodes'] ));
                foreach ( $zone_postcodes as $zone_postcode ) {
                  $postcode_array[] = array(
                    'code' => $zone_postcode,
                    'type'  => 'postcode'
                  );
                }
                $location = array_merge( $location, $postcode_array );
              }
              
            }
          }
        }
        //print_r($location);
      }
      WCFMmp_Shipping_Zone::save_location( $location, $zone_id );
    }
    
  }
  
  /**
    * split woocommerce shipping packages 
    * @since 1.0.0
    * @param array $packages
    * @return array
    */
  public function wcfmmp_split_shipping_packages($packages) {
    // Reset all packages
    global $WCFM;
    $packages = array();
    $split_packages = array();
    foreach (WC()->cart->get_cart() as $item) {
        if ($item['data']->needs_shipping()) {
            $product_id = $item['product_id'];

            $vendor_id = $WCFM->wcfm_vendor_support->wcfm_get_vendor_id_from_product( $product_id );
            if ($vendor_id && wcfmmp_is_shipping_enabled($vendor_id)) {
                $split_packages[$vendor_id][] = $item;
            } else {
                $split_packages[0][] = $item;
            }
        }
    }

    foreach ($split_packages as $vendor_id => $split_package) {
        $packages[$vendor_id] = array(
            'contents' => $split_package,
            'contents_cost' => array_sum(wp_list_pluck($split_package, 'line_total')),
            'applied_coupons' => WC()->cart->get_applied_coupons(),
            'user' => array(
                'ID' => apply_filters( 'wcfm_current_vendor_id', get_current_user_id() ),
            ),
            'destination' => array(
                'country' => WC()->customer->get_shipping_country(),
                'state' => WC()->customer->get_shipping_state(),
                'postcode' => WC()->customer->get_shipping_postcode(),
                'city' => WC()->customer->get_shipping_city(),
                'address' => WC()->customer->get_shipping_address(),
                'address_2' => WC()->customer->get_shipping_address_2()
            ),
            'seller_id' => $vendor_id
        );
    }
    return apply_filters('wcfmmp_split_shipping_packages', $packages);
  }
  
  /**
   * 
   * @param object $item
   * @param sting $package_key as $vendor_id
   */
  public function wcfmmp_add_meta_date_in_shipping_package($item, $package_key, $package, $order) {
      $item->add_meta_data('seller_id', $package_key, true);
      $package_qty = array_sum(wp_list_pluck($package['contents'], 'quantity'));
      $item->add_meta_data('package_qty', $package_qty, true);
      do_action('wcfmmp_add_shipping_package_meta_data');
  }
  
  /**
     * Rename shipping packages 
     * @since 1.0.0
     * @param string $package_name
     * @param string $vendor_id
     * @param array $package
     * @return string
     */
  public function wcfmmp_shipping_package_name($package_name, $vendor_id, $package) {
      if ($vendor_id && $vendor_id != 0) {
          $vendor = get_userdata($vendor_id);
          if ($vendor) {
              return $vendor->display_name . __(' Shipping', 'woocommere-multivendor-shipping');
          }
          return $package_name;
      }
      return $package_name;
    }
  
}